import path from "node:path";
import { MuseError } from "#errors";
import type { Binding } from "./binding";

export type MuseProcessorFn = (
  binding: Binding,
  opts: Record<string, unknown>,
) => Promise<Binding>;

export interface MuseProcessor {
  readonly filePath: string;
  readonly name: string;
  readonly description: string;
  readonly process: MuseProcessorFn;
}

export async function loadProcessor(
  bindingDirname: string,
  processorPath: string,
): Promise<MuseProcessor> {
  // Resolve local paths, use URLs as-is
  const resolvedProcessorPath = processorPath.startsWith("http")
    ? processorPath
    : path.resolve(bindingDirname, processorPath);
  const { process, name, description } = await import(resolvedProcessorPath);

  if (!process || typeof process !== "function") {
    throw new MuseError(
      `Processor at ${processorPath} does not export a process() function`,
    );
  }

  const processorName = String(name ?? "Unnamed Processor");
  const processorDescription = String(description ?? "");

  return {
    filePath: resolvedProcessorPath,
    process: process as MuseProcessor["process"],
    name: processorName,
    description: processorDescription,
  };
}
